[Libreoffice-commits] .: svtools/source

David Tardon dtardon at kemper.freedesktop.org
Tue Feb 15 22:51:27 PST 2011


 svtools/source/config/menuoptions.cxx |   18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

New commits:
commit 1bec3a8d6b984e1a48308425eedacd2e191b7669
Author: Christina Rossmanith <ChrRossmanith at web.de>
Date:   Sat Feb 12 21:19:41 2011 +0100

    fixed spelling menues -> menus

diff --git a/svtools/source/config/menuoptions.cxx b/svtools/source/config/menuoptions.cxx
index a12f1e0..0a4341e 100644
--- a/svtools/source/config/menuoptions.cxx
+++ b/svtools/source/config/menuoptions.cxx
@@ -147,8 +147,8 @@ class SvtMenuOptions_Impl : public ConfigItem
 
         /*-****************************************************************************************************//**
             @short		access method to get internal values
-            @descr		These method give us a chance to regulate acces to ouer internal values.
-                        It's not used in the moment - but it's possible for the feature!
+            @descr		These methods give us a chance to regulate access to our internal values.
+                        It's not used in the moment - but it's possible for the future!
 
             @seealso	-
 
@@ -201,7 +201,7 @@ class SvtMenuOptions_Impl : public ConfigItem
     private:
 
         /*-****************************************************************************************************//**
-            @short		return list of fix key names of ouer configuration management which represent oue module tree
+            @short		return list of fix key names of our configuration management which represent our module tree
             @descr		These methods return a static const list of key names. We need it to get needed values from our
                         configuration management.
 
@@ -250,7 +250,7 @@ SvtMenuOptions_Impl::SvtMenuOptions_Impl()
         bMenuIcons = m_nMenuIcons ? sal_True : sal_False;
     }
 
     // Copy values from list in right order to ouer internal member.
     sal_Int32 nPropertyCount	=	seqValues.getLength()	;
     sal_Int32 nProperty			=	0						;
     for( nProperty=0; nProperty<nPropertyCount; ++nProperty )
@@ -444,9 +444,9 @@ SvtMenuOptions::SvtMenuOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
     // Increase ouer refcount ...
     ++m_nRefCount;
     // ... and initialize ouer data container only if it not already!
     if( m_pDataContainer == NULL )
     {
         RTL_LOGFILE_CONTEXT(aLog, "svtools ( ??? ) ::SvtMenuOptions_Impl::ctor()");
@@ -463,10 +463,10 @@ SvtMenuOptions::~SvtMenuOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
     // Decrease ouer refcount.
     --m_nRefCount;
     // If last instance was deleted ...
     // we must destroy ouer static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
@@ -541,7 +541,7 @@ Mutex& SvtMenuOptions::GetOwnStaticMutex()
         // ... we must create a new one. Protect follow code with the global mutex -
         // It must be - we create a static variable!
         MutexGuard aGuard( Mutex::getGlobalMutex() );
-        // We must check our pointer again - because it can be that another instance of ouer class will be fastr then these!
+        // We must check our pointer again - because it can be that another instance of our class will be faster than these!
         if( pMutex == NULL )
         {
             // Create the new mutex and set it for return on static variable.
@@ -250,7 +250,7 @@ SvtMenuOptions_Impl::SvtMenuOptions_Impl()
     }
 
-    // Copy values from list in right order to ouer internal member.
+    // Copy values from list in right order to our internal member.
     sal_Int32 nPropertyCount	=	seqValues.getLength()	;
     sal_Int32 nProperty			=	0						;
@@ -444,9 +444,9 @@ SvtMenuOptions::SvtMenuOptions()
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
@@ -444,9 +444,9 @@ SvtMenuOptions::SvtMenuOptions()
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already!
+    // ... and initialize our data container only if it not already!
     if( m_pDataContainer == NULL )
     {
@@ -463,10 +463,10 @@ SvtMenuOptions::~SvtMenuOptions()
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
@@ -463,10 +463,10 @@ SvtMenuOptions::~SvtMenuOptions()
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {


More information about the Libreoffice-commits mailing list